##----------------------------------------------------------------------
## R.MEANTEMP.R
## Check East Anglia mean temp. series for appropriate ARIMA model.
## 06/12/2018 (original)
## 04/04/2020 (new version, more years of data)
##----------------------------------------------------------------------
rm(list=ls())  ## caution -- clearout!
## get the data in...
EAST.ANGLIA.MEANTEMP <- read.table('EAST.ANGLIA.MEANTEMP.txt',
    head=T, skip=0, sep='\t')

## Data now run from 1884 to present (04/04/2020)
INIT.YEAR <- 1884L
LAST.YEAR <- 2019L
nyears <- LAST.YEAR - INIT.YEAR + 1
eamt.ann <- EAST.ANGLIA.MEANTEMP[,'ann'] 
eamt.year <- EAST.ANGLIA.MEANTEMP[,'year'] 
eamt <- ts(eamt.ann, start=INIT.YEAR)
eamt
str(eamt)

ADD.LOGO <- F

smallplot <- function(device='console') {
    if(device=='console') {
        win.graph(width = 4, height = 4)
    } else {
        png(filename = "EAST.ANGLIA.MEANTEMP.png",
            width = 400, height = 400, pointsize = 16)
    }
    par(mar=c(4,4,2,1))
    plot(x = eamt.year, y = eamt.ann,
        main = 'East Anglia mean temperatures',
        xlab = 'year', ylab = 'mean temperature',
        pch = 0)
    ma10 <- rep(0., nyears)
    for(jj in 10:nyears){
        ma10[jj] <- mean(eamt.ann[(jj-9):jj])
    }
    ma10[1:9] <- NA
    lines(x = eamt.year, y = ma10, col='red')

    if(ADD.LOGO) { source('add.logo.R', echo=T) }
    if(device!='console') {dev.off()}
}

smallplot('console')
smallplot('png')

lm1 <- lm(eamt.ann ~ eamt.year)
summary(lm1)
str(lm1)
## ...seems to indicate a trend is present, but tests are unreliable

## check correlation structure of original time series...
win.graph()
par(mfrow=c(2,1))
acf(eamt)
acf(eamt, type='part')

## ...also of 1st differences, should remove linear trend
win.graph()
par(mfrow=c(2,1))
acf(diff(eamt))
acf(diff(eamt), type='part')

## conclusions from ACF and PACF
## 1. For raw time series, ACF shows approximately exponential
##    pattern, PACF shows a single spike at lag 1 and a smaller
##    spike at lag 2.
## 2. ACF for 1st differences shows a single (negative) spike at
##    lag 1. PACF (differences) shows negative spike at lag 1,
##    then smaller spike at lag 4 (just outside C.L.).
## 3. Suggests AR(1) correlation structure, expect the
##    the linear trend over Year still to be significant.

## Try to estimate long-term trend using GLS
library(nlme)
## grand-mean, null model
M000.gls <- gls(eamt.ann ~ 1, method='ML')
## test for Year, ignore serial correlation...
M100.gls <- gls(eamt.ann ~ eamt.year, method='ML')
anova(M000.gls, M100.gls)
## allow for AR(1) serial correlation
M110.gls <- update(M100.gls, corr=corARMA(p=1,q=0))
anova(M100.gls, M110.gls)       ## indicates serial correlation     
M120.gls <- update(M100.gls, corr=corARMA(p=2,q=0))
anova(M110.gls, M120.gls)       ## no need for AR(2)

summary(M110.gls)

## check for seasonal component (fails -- no seasonality)
try(stl(eamt))

